@@ -8,7 +8,7 @@ class ImportControllerTest extends WallabagCoreTestCase
 {
     public function testLogin()
     {
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $client->request('GET', '/import/');
 
@@ -19,7 +19,7 @@ class ImportControllerTest extends WallabagCoreTestCase
     public function testImportList()
     {
         $this->logInAs('admin');
-        $client = $this->getClient();
+        $client = $this->getTestClient();
 
         $crawler = $client->request('GET', '/import/');
 
